@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 use base 'Pod::Parser';
 
@@ -40,17 +40,13 @@ sub new {
 	return $new;
 }
 
-sub stopwords { my $self = shift; return $self->{stopwords} }
+sub stopwords { (shift)->{stopwords} }
 
-sub verbatim { return ''; }    # totally ignore verbatim sections
+sub verbatim { '' }    # totally ignore verbatim sections
 
 #----------------------------------------------------------------------
 
-sub _is_debug {
-	my $self = shift;
-
-	return $self->{debug} ? 1 : 0;
-}
+sub _is_debug { (shift)->{debug} ? 1 : 0; }
 
 #----------------------------------------------------------------------
 
@@ -213,7 +209,7 @@ Pod::Spell - a formatter for spellchecking Pod
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -387,18 +383,9 @@ L<podchecker|podchecker> also known as L<Pod::Checker|Pod::Checker>
 
 L<perlpod|perlpod>, L<perlpodspec>
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/pod-spell/issues
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 CONTRIBUTORS
 
-=for stopwords David Golden Kent Fredric Olivier Mengué
+=for stopwords David Golden Kent Fredric Mohammad S Anwar Olivier Mengué
 
 =over 4
 
@@ -412,6 +399,10 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olivier Mengué <dolmen@cpan.org>
 
 =back
@@ -432,7 +423,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing.
+This software is Copyright (c) 2016 by Olivier Mengué.
 
 This is free software, licensed under:
 
