@@ -13,7 +13,7 @@ use Class::Tiny {
 
 use constant MAXWORDLENGTH => 50; ## no critic ( ProhibitConstantPragma )
 
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 our %Wordlist; ## no critic ( Variables::ProhibitPackageVars )
 
@@ -109,7 +109,7 @@ sub strip_stopwords {
 		print "  Keeping as  <$_>\n" if $_ && $self->_is_debug;
 	}
 
-	return join(" ", grep { length } @words );
+	return join(" ", grep { defined && length } @words );
 }
 
 sub _strip_a_word {
@@ -158,7 +158,7 @@ Pod::Wordlist - English words that come up in Perl documentation
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 DESCRIPTION
 
@@ -221,15 +221,6 @@ Coreutils ).
 
 	sort share/wordlist -u > /tmp/sorted && mv /tmp/sorted share/wordlist
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/pod-spell/issues
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHORS
 
 =over 4
@@ -246,7 +237,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Caleb Cushing.
+This software is Copyright (c) 2016 by Olivier Mengué.
 
 This is free software, licensed under:
 
